==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/departments/departmentActions.php <==
<?php 
	require('../assets/inc/ldapConnect.php');
	$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL; // saveDept or deleteDept

	
if ($mode === 'saveDept') {
	$deptMode = (isset($_REQUEST['deptMode']) && strlen($_REQUEST['deptMode']) >=1 ) ? $_REQUEST['deptMode'] : NULL; // addDept or editDept
	$ent = array();
	
	foreach($_REQUEST as $key => $value){
		if (strpos($key, '_') === false) $ent[$key] = $value;
	}
	
	if ($deptMode) {
		
		$cn 				= $ent['cn'];
		$telephonenumber 	= $ent['telephonenumber'];
		$description 		= $ent['description'];
		$deptName 			= $ent['deptName'];
		$deptguid 			= "";
				
				
		unset ($ent['mode']);					
		unset ($ent['cn']);	
		unset ($ent['deptMode']);
		unset ($ent['deptName']);
		unset ($ent['guid']);
		unset ($ent['addmonitor']);
		unset ($ent['addRow']);
		
		
		if (!isset($_REQUEST['messageboxlicense'])) 						$ent['messageboxlicense'] = '0';
		if (!isset($_REQUEST['voicemailenabled'])) 							$ent['voicemailenabled'] = '0';
		if (!isset($_REQUEST['distributionskiponnotargets'])) 				$ent['distributionskiponnotargets'] = '0';
		if (!isset($_REQUEST['alternatedistributionskiponnotargets'])) 		$ent['alternatedistributionskiponnotargets'] = '0';
		
		$ent['company'] = (isset($_REQUEST['company'])) ? $_REQUEST['company'] : $adminCompany;

		
		if ($deptMode === "addDept") {
			$ent['objectclass']		= 'department'; // set objectclass
			ldap_add($ds,"cn=$cn,cn=departments",$ent); 
			$sr = ldap_read($ds,"cn=$cn,cn=departments","objectclass=department",array('guid')); 
			$info = ldap_get_entries($ds,$sr);	$deptguid = $info[0]['guid'][0];
			 
		} else {
			
			ldap_modify($ds, "cn=$deptName, cn=departments", $ent);
			if ($deptName != $cn)
				ldap_rename($ds,"cn=$deptName,cn=departments","cn=$cn","cn=departments",true);
		}
	
		echo "$deptMode:$deptguid:$cn:$telephonenumber:$description";
		audit ("[Department] [$deptMode] $cn");

	}
}



if ($mode === 'deleteDept') {
	$deptName = (isset($_REQUEST['deptName']) && strlen($_REQUEST['deptName']) >=1 ) ? $_REQUEST['deptName'] : NULL;
	ldap_delete($ds, "cn=$deptName, cn=Departments");
	audit ("[Department] [Delete] $deptName");
}


if ($mode === 'vmMonitor') {
$deptGuid = (isset($_REQUEST['deptGuid']) && strlen($_REQUEST['deptGuid']) >=1 ) ? $_REQUEST['deptGuid'] : NULL;
$monitorvalues = (isset($_REQUEST['monitorvaluesArray']) && count($_REQUEST['monitorvaluesArray']) >=1 ) ? $_REQUEST['monitorvaluesArray'] : NULL; // set monitorvalues Array
$blankGuid = '00000000-0000-0000-0000-000000000000';

foreach ($monitorvalues as $key => $value) {
	unset ($exisitng_monitors); unset($ent);
	$parts  = explode(';', $value);
	$mode = $parts[0];
	$userGuid = $parts[1];
	
	if ($mode === 'Exiting') continue;
	
	$vmmon = array('cn','departmentvoicemail','departmentvoicemail2','departmentvoicemail3','departmentvoicemail4','departmentvoicemail5','departmentvoicemail6','departmentvoicemail7','departmentvoicemail8');
	$sr = ldap_search($ds, "cn=Users", "(guid=$userGuid)", $vmmon);
	$info = ldap_get_entries($ds, $sr);
		for ($n=0; $n<$info['count']; $n++) {
			$cn = $info[$n]['cn'][0];
			$exisitng_monitors[] = $info[$n]['departmentvoicemail'][0];	$exisitng_monitors[] = $info[$n]['departmentvoicemail2'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail3'][0]; 
			$exisitng_monitors[] = $info[$n]['departmentvoicemail4'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail5'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail6'][0]; 
			$exisitng_monitors[] = $info[$n]['departmentvoicemail7'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail8'][0];
   		}
		
	for ($i=0; $i<$info["count"]; $i++) {
		
		if ($mode === 'New') {
			
			if ($info[$i]["departmentvoicemail"][0] == $blankGuid) {
					$ent["departmentvoicemail"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail2"][0] == $blankGuid) {
					$ent["departmentvoicemail2"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail3"][0] == $blankGuid) {
					$ent["departmentvoicemail3"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail4"][0] == $blankGuid) {
					$ent["departmentvoicemail4"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail5"][0] == $blankGuid) {
					$ent["departmentvoicemail5"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail6"][0] == $blankGuid) {
					$ent["departmentvoicemail6"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail7"][0] == $blankGuid) {
					$ent["departmentvoicemail7"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail8"][0] == $blankGuid) {
					$ent["departmentvoicemail8"][0] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} else {
					echo "$cn - no free voicemail monitor slots<br/>";
				}
		}
		
		if ($mode === 'Delete')	 {
			if ($info[$i]["departmentvoicemail"][0] == $deptGuid) {
					$ent["departmentvoicemail"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail2"][0] == $deptGuid) {
					$ent["departmentvoicemail2"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail3"][0] == $deptGuid) {
					$ent["departmentvoicemail3"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail4"][0] == $deptGuid) {
					$ent["departmentvoicemail4"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail5"][0] == $deptGuid) {
					$ent["departmentvoicemail5"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail6"][0] == $deptGuid) {
					$ent["departmentvoicemail6"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail7"][0] == $deptGuid) {
					$ent["departmentvoicemail7"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail8"][0] == $deptGuid) {
					$ent["departmentvoicemail8"][0] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} 
		}	
		
	}
	
	audit ("[Department] [Voicemail Monitors] $mode $deptGuid $cn");
}
}


?>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/departments/departmentActions.php <==
<?php 
	require('../assets/inc/ldapConnect.php');
	$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL; // saveDept or deleteDept
	$timestamp = (isset($_REQUEST['timestamp']) && strlen($_REQUEST['timestamp']) >=1 ) ? $_REQUEST['timestamp'] : NULL;

	
if ($mode === 'saveDept') {
	$deptMode = (isset($_REQUEST['deptMode']) && strlen($_REQUEST['deptMode']) >=1 ) ? $_REQUEST['deptMode'] : NULL; // addDept or editDept
	$ent = array();
	
	foreach($_REQUEST as $key => $value){
		if (strpos($key, '_') === false) $ent[$key] = $value;
	}
	
	if ($deptMode) {
		
		$cn 				= $ent['cn'];
		$telephonenumber 	= $ent['telephonenumber'];
		$description 		= $ent['description'];
		$deptName 			= $ent['deptName'];
		$deptguid 			= (isset($ent['guid']) && strlen($ent['guid']) > 1) ? $ent['guid'] : "";		
				
		unset ($ent['mode']);					
		unset ($ent['cn']);	
		unset ($ent['deptMode']);
		unset ($ent['deptName']);
		unset ($ent['guid']);
		unset ($ent['addmonitor']);
		unset ($ent['addRow']);
		unset ($ent['timestamp']);
		
		
		if (!isset($_REQUEST['messageboxlicense'])) 						$ent['messageboxlicense'] = '0';
		if (!isset($_REQUEST['voicemailenabled'])) 							$ent['voicemailenabled'] = '0';
		if (!isset($_REQUEST['distributionskiponnotargets'])) 				$ent['distributionskiponnotargets'] = '0';
		if (!isset($_REQUEST['alternatedistributionskiponnotargets'])) 		$ent['alternatedistributionskiponnotargets'] = '0';
		
		$ent['company'] = (isset($_REQUEST['company'])) ? $_REQUEST['company'] : $adminCompany;

		
		if ($deptMode === "addDept") {
			$ent['objectclass']	= 'department'; // set objectclass
			ldap_add($ds,"cn=$cn,cn=departments",$ent); 
			audit ($timestamp, "[Department] [$deptMode] $cn", $ent);			

			
			$sr = ldap_read($ds,"cn=$cn,cn=departments","objectclass=department",array('guid')); 
			$sr = ldap_search($ds,"cn=departments","(&(objectclass=department)(telephonenumber=$telephonenumber))",array('guid')); 
			$info = ldap_get_entries($ds,$sr);	$deptguid = $info[0]['guid'][0];
			
		} else {
			
			ldap_modify($ds, "guid=$deptguid, cn=departments", $ent);
			audit ($timestamp, "[Department] [$deptMode] $cn", $ent);
			
			if ($deptName != $cn) {
				ldap_rename($ds,"guid=$deptguid,cn=departments","cn=$cn","cn=departments",true);
				audit ($timestamp, "[Department] [Rename Department] $cn", $deptguid);
			}
		}
	
		echo "$deptMode:$deptguid:$cn:$telephonenumber:$description";
	}
}



if ($mode === 'deleteDept') {
	$deptName = (isset($_REQUEST['deptName']) && strlen($_REQUEST['deptName']) >=1 ) ? $_REQUEST['deptName'] : NULL;
	$deptguid = (isset($_REQUEST['deptguid']) && strlen($_REQUEST['deptguid']) >=1 ) ? $_REQUEST['deptguid'] : NULL;
	audit ($timestamp, "[Department] [Delete] $deptName", $deptguid);
	ldap_delete($ds, "guid=$deptguid, cn=Departments");
}


if ($mode === 'vmMonitor') {
$deptGuid = (isset($_REQUEST['deptGuid']) && strlen($_REQUEST['deptGuid']) >=1 ) ? $_REQUEST['deptGuid'] : NULL;
$monitorvalues = (isset($_REQUEST['monitorvaluesArray']) && count($_REQUEST['monitorvaluesArray']) >=1 ) ? $_REQUEST['monitorvaluesArray'] : NULL; // set monitorvalues Array
$blankGuid = '00000000-0000-0000-0000-000000000000';

foreach ($monitorvalues as $key => $value) {
	unset ($exisitng_monitors); unset($ent);
	$parts  = explode(';', $value);
	$mode = $parts[0];
	$userGuid = $parts[1];
	
	if ($mode === 'Exiting') continue;
	
	$vmmon = array('cn','departmentvoicemail','departmentvoicemail2','departmentvoicemail3','departmentvoicemail4','departmentvoicemail5','departmentvoicemail6','departmentvoicemail7','departmentvoicemail8');
	$sr = ldap_search($ds, "cn=Users", "(guid=$userGuid)", $vmmon);
	$info = ldap_get_entries($ds, $sr);
		for ($n=0; $n<$info['count']; $n++) {
			$cn = $info[$n]['cn'][0];
			$exisitng_monitors[] = $info[$n]['departmentvoicemail'][0];	$exisitng_monitors[] = $info[$n]['departmentvoicemail2'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail3'][0]; 
			$exisitng_monitors[] = $info[$n]['departmentvoicemail4'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail5'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail6'][0]; 
			$exisitng_monitors[] = $info[$n]['departmentvoicemail7'][0]; $exisitng_monitors[] = $info[$n]['departmentvoicemail8'][0];
   		}
		
	for ($i=0; $i<$info["count"]; $i++) {
		
		if ($mode === 'New') {
			
			if ($info[$i]["departmentvoicemail"][0] == $blankGuid) {
					$ent["departmentvoicemail"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail2"][0] == $blankGuid) {
					$ent["departmentvoicemail2"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail3"][0] == $blankGuid) {
					$ent["departmentvoicemail3"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail4"][0] == $blankGuid) {
					$ent["departmentvoicemail4"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail5"][0] == $blankGuid) {
					$ent["departmentvoicemail5"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail6"][0] == $blankGuid) {
					$ent["departmentvoicemail6"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail7"][0] == $blankGuid) {
					$ent["departmentvoicemail7"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail8"][0] == $blankGuid) {
					$ent["departmentvoicemail8"] = $deptGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} else {
					echo "$cn - no free voicemail monitor slots<br/>";
				}
		}
		
		if ($mode === 'Delete')	 {
			if ($info[$i]["departmentvoicemail"][0] == $deptGuid) {
					$ent["departmentvoicemail"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail2"][0] == $deptGuid) {
					$ent["departmentvoicemail2"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail3"][0] == $deptGuid) {
					$ent["departmentvoicemail3"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail4"][0] == $deptGuid) {
					$ent["departmentvoicemail4"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail5"][0] == $deptGuid) {
					$ent["departmentvoicemail5"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail6"][0] == $deptGuid) {
					$ent["departmentvoicemail6"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail7"][0] == $deptGuid) {
					$ent["departmentvoicemail7"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} elseif ($info[$i]["departmentvoicemail8"][0] == $deptGuid) {
					$ent["departmentvoicemail8"] = $blankGuid;
					ldap_modify($ds,",cn=$cn, cn=Users", $ent); break;
				} 
		}	
		
	}
	
	audit ($timestamp, "[Department] [Voicemail Monitors] $mode $deptGuid $cn",$ent);
}
}


?>
